@@ -35,3 +35,7 @@ enc2iconv <- function(x, to, ...) {
 choices_rd <- function(x) {
   paste0(collapse = ", ", paste0("\\sQuote{", x, "}"))
 }
+
+lengths <- function(x) {
+  vapply(x, length, integer(1))
+}
